==> PyOpenGL-2.0.0.44.tar.gz: PyOpenGL-2.0.0.44/OpenGL/GL/EXT/texture.py <==
import string
__version__ = string.split('$Revision: 1.10 $')[1]
__date__ = string.join(string.split('$Date: 2001/08/10 18:42:33 $')[1:3], ' ')
__author__ = 'Tarn Weisner Burton <twburton@users.sourceforge.net>'
__doc__ = 'http://oss.sgi.com/projects/ogl-sample/registry/EXT/texture.txt'
__api_version__ = 0x115

ALPHA4_EXT = 0x803B
ALPHA8_EXT = 0x803C
ALPHA12_EXT = 0x803D
ALPHA16_EXT = 0x803E
LUMINANCE4_EXT = 0x803F
LUMINANCE8_EXT = 0x8040
LUMINANCE12_EXT = 0x8041
LUMINANCE16_EXT = 0x8042
LUMINANCE4_ALPHA4_EXT = 0x8043
LUMINANCE6_ALPHA2_EXT = 0x8044
LUMINANCE8_ALPHA8_EXT = 0x8045
LUMINANCE12_ALPHA4_EXT = 0x8046
LUMINANCE12_ALPHA12_EXT = 0x8047
LUMINANCE16_ALPHA16_EXT = 0x8048
INTENSITY_EXT = 0x8049
INTENSITY4_EXT = 0x804A
INTENSITY8_EXT = 0x804B
INTENSITY12_EXT = 0x804C
INTENSITY16_EXT = 0x804D
RGB2_EXT = 0x804E
RGB4_EXT = 0x804F
RGB5_EXT = 0x8050
RGB8_EXT = 0x8051
RGB10_EXT = 0x8052
RGB12_EXT = 0x8053
RGB16_EXT = 0x8054
RGBA2_EXT = 0x8055
RGBA4_EXT = 0x8056
RGB5_A1_EXT = 0x8057
RGBA8_EXT = 0x8058
RGB10_A2_EXT = 0x8059
RGBA12_EXT = 0x805A
RGBA16_EXT = 0x805B

TEXTURE_RED_SIZE_EXT = 0x805C
TEXTURE_GREEN_SIZE_EXT = 0x805D
TEXTURE_BLUE_SIZE_EXT = 0x805E
TEXTURE_ALPHA_SIZE_EXT = 0x805F
TEXTURE_LUMINANCE_SIZE_EXT = 0x8060
TEXTURE_INTENSITY_SIZE_EXT = 0x8061

REPLACE_EXT = 0x8062

PROXY_TEXTURE_1D_EXT = 0x8063

PROXY_TEXTURE_2D_EXT = 0x8064

TEXTURE_TOO_LARGE_EXT = 0x8065

def glInitTextureEXT():
	from OpenGL.GL import __has_extension
	return __has_extension("GL_EXT_texure")

glInitTexEXT = glInitTextureEXT

def __info():
	if glInitTextureEXT():
		return []

==> PyOpenGL-2.0.1.09.tar.gz: PyOpenGL-2.0.1.09/OpenGL/GL/EXT/texture.py <==
import string
__version__ = string.split('$Revision: 1.11 $')[1]
__date__ = string.join(string.split('$Date: 2001/11/17 14:12:34 $')[1:3], ' ')
__author__ = 'Tarn Weisner Burton <twburton@users.sourceforge.net>'
__doc__ = 'http://oss.sgi.com/projects/ogl-sample/registry/EXT/texture.txt'
__api_version__ = 0x115

ALPHA4_EXT = 0x803B
ALPHA8_EXT = 0x803C
ALPHA12_EXT = 0x803D
ALPHA16_EXT = 0x803E
LUMINANCE4_EXT = 0x803F
LUMINANCE8_EXT = 0x8040
LUMINANCE12_EXT = 0x8041
LUMINANCE16_EXT = 0x8042
LUMINANCE4_ALPHA4_EXT = 0x8043
LUMINANCE6_ALPHA2_EXT = 0x8044
LUMINANCE8_ALPHA8_EXT = 0x8045
LUMINANCE12_ALPHA4_EXT = 0x8046
LUMINANCE12_ALPHA12_EXT = 0x8047
LUMINANCE16_ALPHA16_EXT = 0x8048
INTENSITY_EXT = 0x8049
INTENSITY4_EXT = 0x804A
INTENSITY8_EXT = 0x804B
INTENSITY12_EXT = 0x804C
INTENSITY16_EXT = 0x804D
RGB2_EXT = 0x804E
RGB4_EXT = 0x804F
RGB5_EXT = 0x8050
RGB8_EXT = 0x8051
RGB10_EXT = 0x8052
RGB12_EXT = 0x8053
RGB16_EXT = 0x8054
RGBA2_EXT = 0x8055
RGBA4_EXT = 0x8056
RGB5_A1_EXT = 0x8057
RGBA8_EXT = 0x8058
RGB10_A2_EXT = 0x8059
RGBA12_EXT = 0x805A
RGBA16_EXT = 0x805B

TEXTURE_RED_SIZE_EXT = 0x805C
TEXTURE_GREEN_SIZE_EXT = 0x805D
TEXTURE_BLUE_SIZE_EXT = 0x805E
TEXTURE_ALPHA_SIZE_EXT = 0x805F
TEXTURE_LUMINANCE_SIZE_EXT = 0x8060
TEXTURE_INTENSITY_SIZE_EXT = 0x8061

REPLACE_EXT = 0x8062

PROXY_TEXTURE_1D_EXT = 0x8063

PROXY_TEXTURE_2D_EXT = 0x8064

TEXTURE_TOO_LARGE_EXT = 0x8065

def glInitTextureEXT():
	from OpenGL.GL import __has_extension
	return __has_extension("GL_EXT_texture")

glInitTexEXT = glInitTextureEXT

def __info():
	if glInitTextureEXT():
		return []
